Welcome to Druggable Interactor Finder's Documentation!
=======================================================
.. automodule:: drugintfinder

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   installation
   usage
